@@ -45,7 +45,7 @@ sub _new {
     my $class = ref($proto) || $proto;
     my %params = @_;
 
-    my $con = exists $params{connection} ? $params{connection} : die "connection parameter is requried";
+    my $con = exists $params{connection} ? $params{connection} : die "connection parameter is required";
     my $self;
     if (exists $params{name}) {
 	$self = Sys::Virt::Network::_lookup_by_name($con,  $params{name});
@@ -363,7 +363,7 @@ Network lifecycle events
 
 The following constants allow network lifecycle change events to be
 interpreted. The events contain both a state change, and a
-reason though the reason is currently unsed.
+reason though the reason is currently unused.
 
 =over 4
 
